/* ============================================================
 *
 * This file is part of the KDE project
 *
 * Date        : 2007-09-13
 * Description : Sane interface for KDE
 *
 * Copyright (C) 2007-2010 by Kare Sars <kare dot sars at iki dot fi>
 * Copyright (C) 2009 by Grzegorz Kurtyka <grzegorz dot kurtyka at gmail dot com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) version 3, or any
 * later version accepted by the membership of KDE e.V. (or its
 * successor approved by the membership of KDE e.V.), which shall
 * act as a proxy defined in Section 6 of version 3 of the license.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * ============================================================ */

#ifndef SANE_DEVICE_DIALOG_H
#define SANE_DEVICE_DIALOG_H

#include <QDialog>

#include "libqsane_export.h"

#include "sane_device_info.h"

namespace LibQSane
{

class SaneDeviceDialogPrivate;

class LIBQSANE_EXPORT SaneDeviceDialog : public QDialog
{
    Q_OBJECT
public:
    SaneDeviceDialog(QWidget *parent = 0, bool autoSelectSingleDevice = true);
    ~SaneDeviceDialog();

    QString getSelectedName();
    void setDefault(QString);
    
    SaneDeviceInfo getSelectedDevice();

public Q_SLOTS:
    void reloadDevicesList();

private:
    QScopedPointer<SaneDeviceDialogPrivate> d_ptr;
    Q_DECLARE_PRIVATE(SaneDeviceDialog);
    Q_PRIVATE_SLOT(d_func(), void _q_setAvailable(bool));
    Q_PRIVATE_SLOT(d_func(), void _q_updateDevicesList());
};

}  // NameSpace LibQSane

#endif // SANE_DEVICE_DIALOG_H
